@@ -8,7 +8,6 @@ from django.db import models as django_models
 def default_cache_func(
         redis_root,
         django_model,
-        redis_model,
         cache_conf,
 ):
     redis_dicts = redis_root.get(django_model, return_dict=True)
@@ -16,11 +15,11 @@ def default_cache_func(
         redis_root,
         django_model,
         redis_dicts,
+        cache_conf,
     )
     django_to_cache(
         redis_root,
         django_model,
-        redis_model,
         cache_conf,
     )
 
@@ -29,12 +28,13 @@ def cache_to_django(
         redis_root,
         django_model,
         redis_dicts,
+        cache_conf,
 ):
-
     async def run_cache_to_django(
             redis_root,
             django_model,
             redis_dicts,
+            cache_conf,
     ):
         async_chunk_size = redis_root.async_db_requests_limit
         async_tasks = []
@@ -52,13 +52,47 @@ def cache_to_django(
             if len(async_tasks) == async_chunk_size or completed == to_complete:
                 await asyncio.gather(*async_tasks)
                 async_tasks = []
-                print(f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
+                print(
+                    f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
+
+
+        if cache_conf['delete']:
+
+            async def check_if_need_to_delete_django_instance(redis_instances_django_ids, django_instance):
+                if django_instance.id not in redis_instances_django_ids:
+                    django_instance.delete()
+
+            all_redis_instances = redis_root.get(django_model)
+            redis_instances_django_ids = []
+            for redis_instance in all_redis_instances:
+                if 'django_id' in redis_instance.keys():
+                    redis_instances_django_ids.append(redis_instance['django_id'])
+
+            all_django_instances = django_model.objects.all()
+            async_tasks = []
+            completed = 0
+            to_complete = len(all_django_instances)
+            for django_instance in all_django_instances:
+                async_tasks.append(
+                    check_if_need_to_delete_django_instance(
+                        redis_instances_django_ids,
+                        django_instance,
+                    )
+                )
+                completed += 1
+                if len(async_tasks) == async_chunk_size or completed == to_complete:
+                    await asyncio.gather(*async_tasks)
+                    async_tasks = []
+                    print(f'{datetime.datetime.now()} - Deleted {django_model.__name__} instances from django')
+
+            await asyncio.gather(*async_tasks)
 
     loop = asyncio.get_event_loop()
     loop.run_until_complete(run_cache_to_django(
         redis_root,
         django_model,
         redis_dicts,
+        cache_conf,
     ))
 
 
@@ -66,7 +100,6 @@ async def update_or_create_django_instance_from_redis_instance(
         redis_instance,
         django_model,
 ):
-    print(redis_instance['id'], redis_instance['django_id'])
     django_id = redis_instance['django_id']
     django_params, django_many_to_many_params = await async_redis_dict_to_django_params(
         redis_instance,
@@ -173,6 +206,7 @@ async def async_redis_dict_to_django_params(
 
     return django_params, django_many_to_many_params
 
+
 @sync_to_async
 def sync_to_async_get_model_fields(django_model):
     return list(django_model._meta.get_fields())
@@ -264,13 +298,11 @@ def django_sync_to_async_create(
 def django_to_cache(
         redis_root,
         django_model,
-        redis_model,
         cache_conf,
 ):
     async def run_django_to_cache(
             redis_root,
             django_model,
-            redis_model,
             cache_conf,
     ):
         filter_by = cache_conf['filter_by']
@@ -288,7 +320,6 @@ def django_to_cache(
                 update_or_create_redis_instance_from_django_instance(
                     redis_root,
                     django_instance,
-                    redis_model,
                     cache_conf,
                 )
             )
@@ -299,12 +330,28 @@ def django_to_cache(
                 print(
                     f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from django to cache')
 
+        if cache_conf['delete']:
+            async def check_if_need_to_delete_redis_instance(redis_root, django_instances_ids, redis_instance):
+                if 'django_id' in redis_instance.keys():
+                    if redis_instance['django_id'] not in django_instances_ids:
+                        redis_root.delete(django_model, redis_instance)
+
+            django_instances_ids = [django_instance.id for django_instance in django_instances]
+            all_redis_instances = redis_root.get(django_model)
+            async_tasks = [
+                check_if_need_to_delete_redis_instance(redis_root, django_instances_ids, redis_instance)
+                for redis_instance in all_redis_instances
+            ]
+
+            await asyncio.gather(*async_tasks)
+
+    print(f'{datetime.datetime.now()} - Deleted {django_model.__name__} instances from cache')
+
     loop = asyncio.get_event_loop()
     loop.run_until_complete(
         run_django_to_cache(
             redis_root,
             django_model,
-            redis_model,
             cache_conf,
         )
     )
@@ -313,18 +360,17 @@ def django_to_cache(
 async def update_or_create_redis_instance_from_django_instance(
         redis_root,
         django_instance,
-        redis_model,
         cache_conf,
 ):
     django_instance_model = django_instance.__class__
-    redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
+    old_redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
     redis_dict = await django_instance_to_redis_params(
         redis_root,
         django_instance,
         cache_conf,
     )
 
-    if not redis_instance:
+    if not old_redis_instance:
         fields_to_create = redis_dict
         redis_instance = redis_root.create(
             django_model=django_instance_model,
@@ -333,14 +379,15 @@ async def update_or_create_redis_instance_from_django_instance(
         )
         result_redis_instance_id = redis_instance['id']
     else:
-        redis_instance = redis_instance[0]
+        old_redis_instance = old_redis_instance[0]
         fields_to_update = check_fields_need_to_update(
-            redis_instance,
+            old_redis_instance,
             redis_dict,
         )
-        redis_root.update(django_instance_model, redis_instance,
+        redis_root.update(django_instance_model, old_redis_instance,
                           **fields_to_update
                           )
+        redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
         result_redis_instance_id = redis_instance['id']
 
     return result_redis_instance_id
@@ -420,7 +467,6 @@ async def django_instance_to_redis_params(
             allowed = True
             if exclude_fields:
                 allowed = (django_field.name not in exclude_fields)
-                print(allowed, django_field.name)
             if allowed:
                 if django_field.name not in ['id', 'pk']:
                     redis_param = await django_instance_field_to_redis_value(
