@@ -463,7 +463,6 @@ class RedisRoot:
             for django_field in django_model._meta.get_fields():
                 django_field_name = django_field.name
                 allowed = True
-                print(exclude_fields)
                 if exclude_fields:
                     allowed = (django_field.name not in exclude_fields)
                 if allowed:
@@ -594,7 +593,6 @@ class RedisRoot:
             cache_func(
                 self,
                 django_model,
-                redis_model,
                 cache_conf,
             )
             print(f'{datetime.datetime.now()} - Cached {django_model} successfully')
@@ -645,6 +643,7 @@ class RedisRoot:
             'cache_func': default_cache_func,
             'exclude_fields': [],
             'filter_by': {},
+            'delete': False,
         }
         if user_cache_conf is not None:
             if type(user_cache_conf) == dict:
@@ -691,6 +690,11 @@ class RedisRoot:
                             raise Exception(f'{name} -> cache config -> filter_by -> all keys must be strings')
                     else:
                         raise Exception(f'{name} -> cache config -> filter_by must be dict')
+                if 'delete' in user_cache_conf.keys():
+                    if type(user_cache_conf['delete']) == bool:
+                        cache_conf['delete'] = user_cache_conf['delete']
+                    else:
+                        raise Exception(f'{name} -> cache config -> delete must be bool')
             else:
                 raise Exception(f'{name} -> cache config must be dict')
 
@@ -944,13 +948,13 @@ class RedisRoot:
     def _update_by_instance_key(self, instance_key, fields_to_update, renew_ttl, new_ttl):
         updated_data = None
         prefix, model_name, instance_id = instance_key.split(':')
-        saved_model = self._get_registered_model_by_name(model_name)
+        redis_model = self._get_registered_model_by_name(model_name)
         instance_id = int(instance_id)
         instance_data_json = self.redis_instance.get(instance_key)
         instance_data = json.loads(instance_data_json)
         data_to_write = {}
         for field_name, field_data in instance_data.items():
-            saved_field_instance = self._get_field_instance_by_name(field_name, saved_model)
+            saved_field_instance = self._get_field_instance_by_name(field_name, redis_model)
             if field_name in fields_to_update.keys():
                 saved_field_instance.value = fields_to_update[field_name]
                 cleaned_value = saved_field_instance.clean()
@@ -962,13 +966,13 @@ class RedisRoot:
         for instance_key, fields_to_write in data_to_write.items():
             ttl = None
             if renew_ttl:
-                ttl = saved_model.get_model_ttl()
+                ttl = redis_model.get_model_ttl()
             elif new_ttl:
                 ttl = new_ttl
             fields_to_write_json = json.dumps(fields_to_write)
             self.redis_instance.set(instance_key, fields_to_write_json, ex=ttl)
             updated_data = {
-                'django_model': saved_model,
+                'redis_model': redis_model,
                 'id': instance_id
             }
         return updated_data
@@ -991,12 +995,12 @@ class RedisRoot:
                         updated_datas.append(updated_data)
         updated_instances = {}
         for updated_data in updated_datas:
-            updated_model = updated_data['django_model']
+            updated_redis_model = updated_data['redis_model']
             updated_id = updated_data['id']
             if self.economy:
                 updated_instances[updated_id] = {'id': updated_id}
             else:
-                updated_instance_qs = self.get(updated_model, id=updated_id)
+                updated_instance_qs = self.get_by_redis_model(updated_redis_model, id=updated_id)
                 updated_instance = updated_instance_qs[0]
                 updated_instances[updated_id] = updated_instance
         return self._return_with_format(updated_instances, return_dict)
@@ -1038,12 +1042,8 @@ class RedisRoot:
     #     return result
 
     def create(self, django_model, **params):
-        model = self._django_model_to_redis_model(django_model)
-        redis_instance_id = model(redis_root=self, **params).save()
-        if self.economy:
-            redis_instances = {'id': redis_instance_id}
-        else:
-            redis_instance = self.get(django_model, id=redis_instance_id)
+        redis_model = self._django_model_to_redis_model(django_model)
+        redis_instance = redis_model(redis_root=self, **params).save()
         return redis_instance
 
 
@@ -1105,7 +1105,6 @@ class RedisModel:
         self.__model_data__['fields'] = fields
 
     def _fill_fields_values(self, field_values_dict):
-        print('_fill_fields_values', field_values_dict)
         for name, value in field_values_dict.items():
             fields = self.__model_data__['fields']
             if name in fields.keys():
@@ -1123,15 +1122,11 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
-                    print(field_name, field.value)
                     cleaned_value = field.clean()
-                    if instance_key not in cleaned_fields.keys():
-                        cleaned_fields[instance_key] = {}
-                    cleaned_fields[instance_key][field_name] = cleaned_value
+                    cleaned_fields[field_name] = cleaned_value
                 except BaseException as ex:
                     raise Exception(f'{ex} ({name} -> {field_name})')
-        fields_with_model_key = cleaned_fields
-        return fields_with_model_key
+        return instance_key, cleaned_fields
     
     def get_model_ttl(self):
         ttl = None
@@ -1141,17 +1136,14 @@ class RedisModel:
         return ttl
 
     def _set_fields(self):
-        data_to_write = self._serialize_data()
+        instance_key, fields_dict = self._serialize_data()
         model_ttl = self.get_model_ttl()
         redis_root = self.__model_data__['redis_root']
-        saved_instance = {}
-        for instance_key, fields_dict in data_to_write.items():
-            prefix, model_name, instance_id = instance_key.split(':')
-            redis_instance = redis_root.redis_instance
-            fields_json = json.dumps(fields_dict)
-            redis_instance.set(instance_key, fields_json, ex=model_ttl)
-            if instance_id not in saved_instance.keys():
-                saved_instance[instance_id] = fields_dict
+        prefix, model_name, instance_id = instance_key.split(':')
+        redis_instance = redis_root.redis_instance
+        fields_json = json.dumps(fields_dict)
+        redis_instance.set(instance_key, fields_json, ex=model_ttl)
+        saved_instance = fields_dict
         return saved_instance
 
     def _get_new_id(self):
